"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const command_1 = require("../command");
exports.prepackCommand = command_1.createCommand((api) => {
    const { config, reporter } = api;
    return {
        command: "prepack",
        describe: "Prepares a package",
        handler() {
            const cwd = process.cwd();
            const srcPackageJson = readPackageJson(cwd);
            const fullName = srcPackageJson.name;
            if ((config.ignore || []).includes(fullName)) {
                reporter.warn(`Ignored ${fullName}`);
                return;
            }
            const distPackageJson = readPackageJson(path_1.join(cwd, "./dist"));
            distPackageJson.version = srcPackageJson.version;
            if ("dependencies" in srcPackageJson) {
                distPackageJson.dependencies = srcPackageJson.dependencies;
            }
            if ("peerDependencies" in srcPackageJson) {
                distPackageJson.peerDependencies = srcPackageJson.peerDependencies;
            }
            if ("optionalDependencies" in srcPackageJson) {
                distPackageJson.optionalDependencies =
                    srcPackageJson.optionalDependencies;
            }
            if ("sideEffects" in srcPackageJson) {
                distPackageJson.sideEffects = srcPackageJson.sideEffects;
            }
            fs_1.writeFileSync(path_1.join(cwd, "./dist/package.json"), JSON.stringify(distPackageJson, null, 2));
        },
    };
});
function readPackageJson(path) {
    return JSON.parse(fs_1.readFileSync(path_1.join(path, "./package.json"), {
        encoding: "utf-8",
    }));
}
