#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const yargs_1 = tslib_1.__importDefault(require("yargs"));
const consola_1 = tslib_1.__importDefault(require("consola"));
const config_1 = require("./config");
const build_1 = require("./commands/build");
const prepack_1 = require("./commands/prepack");
const run_1 = require("./commands/run");
const validate_1 = require("./commands/validate");
async function main() {
    const config = await config_1.useConfig();
    const root = yargs_1.default.scriptName("bob").detectLocale(false).version();
    const commands = [
        build_1.buildCommand,
        prepack_1.prepackCommand,
        run_1.runCommand,
        validate_1.validateCommand,
    ];
    const reporter = consola_1.default.create({});
    commands
        .reduce((cli, cmd) => cli.command(cmd({ config, reporter })), root)
        .help()
        .showHelpOnFail(false).argv;
}
main();
